clear
drop _all

use "C:\LeeBellemareJDSMobilePhones.dta"


* Table 2 *

xi: mean onion_price age female single educ hhsize depr income land cult_area amort mortgage rent gm_ffs gm_coop gm_ia gm_fa mp_hh mp_farmer mp_spouse mp_children brgy1 brgy2 brgy3 [pweight=weight]

* Table 3 *

ttest ln_onion_price, by(mp_hh) unequal
ttest ln_onion_price, by(mp_farmer) unequal
ttest ln_onion_price, by(mp_spouse) unequal
ttest ln_onion_price, by(mp_children) unequal

* Table 4 *

reg ln_onion_price age female single educ hhsize depr income land cult_area mp_hh [pweight=weight], robust
gen marg = exp(_b[mp_hh] - 0.5*((_se[mp_hh])^2))-1
mean marg
drop marg


reg ln_onion_price age female single educ hhsize depr income land cult_area amort mortgage rent mp_hh [pweight=weight], robust
gen marg = exp(_b[mp_hh] - 0.5*((_se[mp_hh])^2))-1
mean marg
drop marg


reg ln_onion_price age female single educ hhsize depr income land cult_area amort mortgage rent gm_ffs gm_coop gm_ia gm_fa mp_hh i.brgy [pweight=weight], robust
gen marg = exp(_b[mp_hh] - 0.5*((_se[mp_hh])^2))-1
mean marg
drop marg

* Table 5 *

reg ln_onion_price age female single educ hhsize depr income land cult_area mp_farmer mp_spouse mp_children [pweight=weight], robust
gen marg = exp(_b[mp_farmer] - 0.5*((_se[mp_farmer])^2))-1
mean marg
drop marg


reg ln_onion_price age female single educ hhsize depr income land cult_area amort mortgage rent mp_farmer mp_spouse mp_children [pweight=weight], robust
gen marg = exp(_b[mp_farmer] - 0.5*((_se[mp_farmer])^2))-1
mean marg
drop marg


reg ln_onion_price age female single educ hhsize depr income land cult_area amort mortgage rent gm_ffs gm_coop gm_ia gm_fa mp_farmer mp_spouse mp_children i.brgy [pweight=weight], robust
gen marg_0 = exp(_b[mp_farmer] - 0.5*((_se[mp_farmer])^2))-1
mean marg_0
drop marg_0

* Table 6 *

xi: robreg m ln_onion_price age female single educ hhsize depr income land cult_area amort mortgage rent gm_ffs gm_coop gm_ia gm_fa mp_farmer mp_spouse mp_children i.brgy
test mp_farmer = mp_spouse = mp_children
test mp_farmer = mp_spouse
test mp_farmer = mp_children
test mp_spouse = mp_children


qreg ln_onion_price age female single educ hhsize depr income land cult_area amort mortgage rent gm_ffs gm_coop gm_ia gm_fa mp_farmer mp_spouse mp_children brgy1 brgy2
test mp_farmer = mp_spouse = mp_children
test mp_farmer = mp_spouse
test mp_farmer = mp_children
test mp_spouse = mp_children


xi: mmregress ln_onion_price age educ hhsize depr income land cult_area, dummies(female single amort mortgage rent gm_ffs gm_coop gm_ia gm_fa mp_farmer mp_spouse mp_children i.brgy)
test mp_farmer = mp_spouse = mp_children
test mp_farmer = mp_spouse
test mp_farmer = mp_children
test mp_spouse = mp_children

xi: sregress ln_onion_price age female single educ hhsize depr income land cult_area amort mortgage rent gm_ffs gm_coop gm_ia gm_fa mp_farmer mp_spouse mp_children brgy2 brgy3
test mp_farmer = mp_spouse = mp_children
test mp_farmer = mp_spouse
test mp_farmer = mp_children
test mp_spouse = mp_children

xi: sregress ln_onion_price age female single educ hhsize depr income land cult_area amort mortgage rent gm_ffs gm_coop gm_ia gm_fa mp_farmer mp_spouse mp_children brgy2 brgy3
test mp_farmer = mp_spouse
test mp_farmer = mp_children
test mp_spouse = mp_children

xi: msregress ln_onion_price age educ hhsize depr income land cult_area, dummies(female single amort mortgage rent gm_ffs gm_coop gm_ia gm_fa mp_farmer mp_spouse mp_children i.brgy)
test mp_farmer = mp_spouse = mp_children
test mp_farmer = mp_spouse
test mp_farmer = mp_children
test mp_spouse = mp_children


* Appendix *

* Figures 1 and 2 *

kdensity ln_onion_price, epan w(0.1) title(Distribution of Onion Price)

twoway (kdensity ln_onion_price if mp_hh==0, w(0.1) epanechnikov) (kdensity ln_onion_price if mp_hh==1, w(0.1) epanechnikov lpattern(dash)), legend(label(1 "Does Not Own a MP") label(2 "Household Owns a MP")) title(Distribution of Onion Price by Mobile Phone Ownership) ytitle(Density) xtitle(Log of Onion Price)


* Propensity Score Matching Analysis *

* Table A1 *

xi: pscore mp_hh age single educ hhsize depr income land cult_area amort mortgage rent gm_ffs gm_coop gm_ia gm_fa i.brgy [pweight=weight], pscore(mp)

* Table A2 *

reg ln_onion_price age female single educ hhsize depr income land cult_area mp [pweight=weight], robust
gen marg = exp(_b[mp] - 0.5*((_se[mp])^2))-1
mean marg
drop marg

reg ln_onion_price age female single educ hhsize depr income land cult_area amort mortgage rent mp [pweight=weight], robust
gen marg = exp(_b[mp] - 0.5*((_se[mp])^2))-1
mean marg
drop marg

reg ln_onion_price age female single educ hhsize depr income land cult_area amort mortgage rent gm_ffs gm_coop gm_ia gm_fa mp i.brgy [pweight=weight], robust
gen marg = exp(_b[mp] - 0.5*((_se[mp])^2))-1
mean marg
drop marg

* Table A3 *

set seed 123456789
reg ln_onion_price age female single educ hhsize depr income land cult_area mp_hh, vce(bootstrap, reps(1000))
gen marg = exp(_b[mp_hh] - 0.5*((_se[mp_hh])^2))-1
mean marg
drop marg


set seed 123456789
reg ln_onion_price age female single educ hhsize depr income land cult_area amort mortgage rent mp_hh, vce(bootstrap, reps(1000))
gen marg = exp(_b[mp_hh] - 0.5*((_se[mp_hh])^2))-1
mean marg
drop marg


set seed 123456789
reg ln_onion_price age female single educ hhsize depr income land cult_area amort mortgage rent gm_ffs gm_coop gm_ia gm_fa mp_hh i.brgy, vce(bootstrap, reps(1000))
gen marg = exp(_b[mp_hh] - 0.5*((_se[mp_hh])^2))-1
mean marg
drop marg

* Table A4 *

set seed 123456789
reg ln_onion_price age female single educ hhsize depr income land cult_area mp_farmer mp_spouse mp_children, vce(bootstrap, reps(1000))
gen marg = exp(_b[mp_farmer] - 0.5*((_se[mp_farmer])^2))-1
mean marg
drop marg


set seed 123456789
reg ln_onion_price age female single educ hhsize depr income land cult_area amort mortgage rent mp_farmer mp_spouse mp_children, vce(bootstrap, reps(1000))
gen marg = exp(_b[mp_farmer] - 0.5*((_se[mp_farmer])^2))-1
mean marg
drop marg


set seed 123456789
reg ln_onion_price age female single educ hhsize depr income land cult_area amort mortgage rent gm_ffs gm_coop gm_ia gm_fa mp_farmer mp_spouse mp_children i.brgy, vce(bootstrap, reps(1000))
gen marg_0 = exp(_b[mp_farmer] - 0.5*((_se[mp_farmer])^2))-1
mean marg_0
drop marg_0

* Table A5 *

set seed 123456789
sample 90
xi: reg ln_onion_price age female single educ hhsize depr income land cult_area amort mortgage rent gm_ffs gm_coop gm_ia gm_fa mp_farmer mp_spouse mp_children i.brgy [pweight=weight], robust

log close

